@@ -1,5 +1,3 @@
-from re import S
-from tkinter import SW
 from django.utils.decorators import method_decorator
 
 from drf_yasg.utils import swagger_auto_schema
